@@ -75,8 +75,8 @@ foreach my $file (@files) {
         {
             'x'            => 1,
             'y'            => 1,
-            'width'        => $XX * .95,
-            'height'       => $F->{'H_CLIP'} * .95,
+            'width'        => $XX * .90,
+            'height'       => $F->{'H_CLIP'} * .90,
             'file'         => "$images_path/$file",
             'convertalpha' => ($file =~ /wolf/i) ? 1 : 0,
             'center'       => CENTER_XY,
@@ -165,11 +165,12 @@ color_replace_no_clipping();
 
 blitting();
 rotate();
-monochrome(flipping());
+flipping();
+monochrome();
 or_drawing();
 xor_drawing();
 and_drawing();
-alpha_drawing() unless ($rpi);
+alpha_drawing(); # unless ($rpi);
 mask_drawing();
 unmask_drawing();
 animated();
@@ -186,9 +187,9 @@ sub color_mapping {
         {
             'filled'   => 1,
             'x'        => 0,
-            'y'        => 0,
+            'y'        => $F->{'Y_CLIP'},
             'width'    => $XX,
-            'height'   => $YY,
+            'height'   => $F->{'H_CLIP'},
             'gradient' => {
                 'direction' => 'horizontal',
                 'colors'    => {
@@ -205,9 +206,9 @@ sub color_mapping {
         {
             'filled'   => 1,
             'x'        => 0,
-            'y'        => 0,
+            'y'        => $F->{'Y_CLIP'},
             'width'    => $XX,
-            'height'   => $YY,
+            'height'   => $F->{'H_CLIP'},
             'gradient' => {
                 'direction' => 'vertical',
                 'colors'    => {
@@ -1305,19 +1306,20 @@ sub rotate {
 
         my $st = 'Counter-Clockwise Rotate Test ';
         unless ($p) {
-            $st .= 'Using Perl algorithm';
+            $st .= 'Using Standard Quslity Setting';
         } else {
-            $st .= 'Using Imager Library';
+            $st .= 'Using High Qualiuty Setting';
         }
         print_it($F, $st);
         my $s = time + ($factor * 2);
         my $count = 0;
-        $F->acceleration($p);
+
         while (time < $s || $count < 6) {
             my $rot = $F->blit_transform(
                 {
                     'rotate' => {
-                        'degrees' => $angle
+                        'degrees' => $angle,
+                        'quality'   => ($p) ? 'high' : 'quick',
                     },
                     'blit_data' => $image,
                 }
@@ -1339,9 +1341,9 @@ sub rotate {
         $angle = 0;
         $st    = 'Clockwise Rotate Test ';
         unless ($p) {
-            $st .= 'Using Perl algorithm';
+            $st .= 'Using Standard Quality Setting';
         } else {
-            $st .= 'Using Imager Library';
+            $st .= 'Using High Quality Setting';
         }
         print_it($F, $st);
         $s = time + ($factor * 2);
@@ -1350,7 +1352,8 @@ sub rotate {
             my $rot = $F->blit_transform(
                 {
                     'rotate' => {
-                        'degrees' => $angle
+                        'degrees' => $angle,
+                        'quality'   => ($p) ? 'high' : 'quick',
                     },
                     'blit_data' => $image,
                     'perl_only' => $p
@@ -1371,16 +1374,17 @@ sub rotate {
         } ## end while (time < $s || $count...)
         last if ($F->{'BITS'} == 16);
     } ## end foreach my $p (0 .. 1)
-    $F->acceleration(1);
+
 } ## end sub rotate
 
 sub flipping {
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
-    
 
     $image->{'y'} = $F->{'Y_CLIP'};
-    my $s = time + $factor;
+    my $s = time + $factor * 2;
+    my $zoom = time + $factor;
     while (time < $s) {
+#        foreach my $dir (qw(normal vertical horizontal)) {
         foreach my $dir (qw(normal horizontal vertical both)) {
             my $rot = $F->blit_transform(
                 {
@@ -1393,15 +1397,13 @@ sub flipping {
             print_it($F, "Testing Image Flip $dir");
             $F->blit_write($rot);
 
-            #            sleep .3;
+            sleep .3 if (time < $zoom);
         } ## end foreach my $dir (qw(normal horizontal vertical both))
     } ## end while (time < $s)
-    return ($image);
 } ## end sub flipping
 
 sub monochrome {
     my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
-    
 
     print_it($F, 'Testing Monochrome Image blitting');
 
@@ -1486,7 +1488,7 @@ sub animated {
                     } ## end while (time <= $s)
                 } ## end if (defined($image))
             } ## end foreach my $bench (0 .. 1)
-            last if ($XX <= 320 || $rpi);
+#            last if ($XX <= 320 || $rpi);
         } ## end for my $count (0 .. 1)
     } ## end foreach my $info (@list)
 } ## end sub animated
@@ -1495,12 +1497,16 @@ sub or_drawing {
     
     print_it($F, 'Testing OR Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-    my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image2;
+    do {
+        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    } until ($image2->{'image'} ne $image->{'image'});
 
-    $F->or_mode();
+    $F->normal_mode();
     $F->blit_write($image);
     sleep 2;
-    
+
+    $F->or_mode();
     $F->blit_write($image2);
     sleep 2;
     
@@ -1509,13 +1515,9 @@ sub or_drawing {
 
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
     $F->circle({ 'x' => $mid - ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
     $F->circle({ 'x' => $mid, 'y' => $F->{'Y_CLIP'} + $size, 'radius' => $size, 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
     $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
@@ -1526,25 +1528,25 @@ sub xor_drawing {
             
     print_it($F, 'Testing XOR Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-    my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image2;
+    do {
+        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    } until ($image2->{'image'} ne $image->{'image'});
 
-    $F->xor_mode();
+    $F->normal_mode();
     $F->blit_write($image);
     sleep 2;
     
+    $F->xor_mode();
     $F->blit_write($image2);
     sleep 2;
     
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255 });
     $F->rbox({ 'x' => 0, 'y' => 0, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255 });
     $F->rbox({ 'x' => $XX / 4, 'y' => $YY / 4, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
@@ -1555,32 +1557,30 @@ sub and_drawing {
     
     print_it($F, 'Testing AND Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-    my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image2;
+    do {
+        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    } until ($image2->{'image'} ne $image->{'image'});
 
     $F->set_b_color({ 'red' => 255, 'green' => 255, 'blue' => 255 });
     
+    $F->normal_mode();
     $F->cls();
-    $F->and_mode();
     $F->blit_write($image);
-    sleep 1;
-    
+    sleep 2;
+
+    $F->and_mode();
     $F->blit_write($image2);
-    sleep 1;
+    sleep 2;
     
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
     my $mid  = int($XX / 2);
 
-    sleep .1;
-    
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
     $F->circle({ 'x' => $mid - ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
     $F->circle({ 'x' => $mid, 'y' => $F->{'Y_CLIP'} + $size, 'radius' => $size, 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
     $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
@@ -1593,27 +1593,27 @@ sub alpha_drawing {
     $F->attribute_reset();
     print_it($F, 'Testing Alpha Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-    my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image2;
+    do {
+        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    } until ($image2->{'image'} ne $image->{'image'});
     my $size   = length($image2->{'image'}) / $F->{'BYTES'};
     $image2->{'image'} &= pack('C4', 255, 255, 255, 0) x $size;
     $image2->{'image'} |= pack('C4', 0, 0, 0, 128) x $size;
+
+    $F->normal_mode();
     $F->blit_write($image);
     sleep 2;
     
     $F->alpha_mode();
     $F->blit_write($image2);
     sleep 2;
-    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255, 'alpha' => rand(256) });
     $F->rbox({ 'x' => 0, 'y' => 0, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255, 'alpha' => rand(256) });
     $F->rbox({ 'x' => $XX / 4, 'y' => $YY / 4, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-    sleep .1;
-    
 
     $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0, 'alpha' => rand(256) });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
@@ -1623,27 +1623,37 @@ sub alpha_drawing {
 sub mask_drawing {
     
     $F->attribute_reset();
-    print_it($F, 'Testing MASK Drawing Mode (This may be SLOW)');
+    print_it($F, 'Testing MASK Drawing Mode');
 
     $F->set_b_color({ 'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 0 });
     my $h      = int($YY - $F->{'Y_CLIP'});
-    my $image1 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image1;
     my $image2 = $IMAGES[$BW];
+    do {
+        $image1 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    } until ($image2->{'image'} ne $image1->{'image'});
+    $F->normal_mode();
     $F->blit_write($image1);
     $F->mask_mode();
+    sleep .3;
     $F->blit_write($image2);
     sleep $factor;
 } ## end sub mask_drawing
 
 sub unmask_drawing {
     
-    print_it($F, 'Testing UNMASK Drawing Mode (This may be SLOW)');
+    print_it($F, 'Testing UNMASK Drawing Mode');
 
     my $h      = int($YY - $F->{'Y_CLIP'});
-    my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image2;
     my $image1 = $IMAGES[$BW];
+    do {
+        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
+    } until ($image2->{'image'} ne $image1->{'image'});
+    $F->normal_mode();
     $F->blit_write($image1);
     $F->unmask_mode();
+    sleep .3;
     $F->blit_write($image2);
 
     sleep $factor;
