@@ -607,7 +607,7 @@ sub splash {
                         'height'       => 110  * $vf,
                         'wscale'       => 1.5,
                         'color'        => '00FFFFFF',
-                        'text'         => 'Imager Assisted',
+                        'text'         => 'Accelerated',
                         'bounding_box' => TRUE,
                         'center'       => 0,
                         'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
